@@ -37,7 +37,7 @@ class UavsarScene():
 
     def __init__(self, url, work_dir, debug = False):
         self.url = url
-        self.work_dir = work_dir
+        self.work_dir = os.path.expanduser(work_dir)
         self.debug = debug
 
 
@@ -49,7 +49,6 @@ class UavsarScene():
             ann (bool): download associated annotation file? [default = True]
         """
         out_dir = os.path.join(self.work_dir, sub_dir)
-        out_dir = os.path.expanduser(out_dir)
 
         if not os.path.exists(out_dir):
             os.makedirs(out_dir)
